![](https://raw.githubusercontent.com/CheeseCake87/Flask-BigApp/master/app/theme/static/img/Flask-BigApp-Logo.png)

# Flask-BigApp

`pip install Flask-BigApp`

![Tests](https://github.com/CheeseCake87/Flask-BigApp/actions/workflows/tests.yml/badge.svg)

**What is Flask-BigApp?**

Flask-BigApp's main purpose is to help simplify the importing of blueprints, routes and models.
It has a few extra features built in to help with theming, securing pages and password authentication.

[Go to Wiki](https://github.com/CheeseCake87/Flask-BigApp/wiki)
